@@ -110,6 +110,16 @@ QString KConfigSkeletonItem::whatsThis() const
     return d->mWhatsThis;
 }
 
+void KConfigSkeletonItem::setWriteFlags(KConfigBase::WriteConfigFlags flags)
+{
+    d->mWriteFlags = flags;
+}
+
+KConfigBase::WriteConfigFlags KConfigSkeletonItem::writeFlags() const
+{
+    return d->mWriteFlags;
+}
+
 QVariant KConfigSkeletonItem::minValue() const
 {
     return QVariant();
@@ -144,13 +154,13 @@ void KCoreConfigSkeleton::ItemString::writeConfig(KConfig *config)
     if (mReference != mLoadedValue) { // WABA: Is this test needed?
         KConfigGroup cg(config, mGroup);
         if ((mDefault == mReference) && !cg.hasDefault(mKey)) {
-            cg.revertToDefault(mKey);
+            cg.revertToDefault(mKey, writeFlags());
         } else if (mType == Path) {
-            cg.writePathEntry(mKey, mReference);
+            cg.writePathEntry(mKey, mReference, writeFlags());
         } else if (mType == Password) {
-            cg.writeEntry(mKey, obscuredString(mReference));
+            cg.writeEntry(mKey, obscuredString(mReference), writeFlags());
         } else {
-            cg.writeEntry(mKey, mReference);
+            cg.writeEntry(mKey, mReference, writeFlags());
         }
         mLoadedValue = mReference;
     }
@@ -215,9 +225,9 @@ void KCoreConfigSkeleton::ItemUrl::writeConfig(KConfig *config)
     if (mReference != mLoadedValue) { // WABA: Is this test needed?
         KConfigGroup cg(config, mGroup);
         if ((mDefault == mReference) && !cg.hasDefault(mKey)) {
-            cg.revertToDefault(mKey);
+            cg.revertToDefault(mKey, writeFlags());
         } else {
-            cg.writeEntry<QString>(mKey, mReference.toString());
+            cg.writeEntry<QString>(mKey, mReference.toString(), writeFlags());
         }
         mLoadedValue = mReference;
     }
@@ -245,7 +255,7 @@ bool KCoreConfigSkeleton::ItemUrl::isEqual(const QVariant &v) const
 
 QVariant KCoreConfigSkeleton::ItemUrl::property() const
 {
-    return qVariantFromValue<QUrl>(mReference);
+    return QVariant::fromValue<QUrl>(mReference);
 }
 
 KCoreConfigSkeleton::ItemProperty::ItemProperty(const QString &_group,
@@ -479,11 +489,11 @@ void KCoreConfigSkeleton::ItemEnum::writeConfig(KConfig *config)
     if (mReference != mLoadedValue) { // WABA: Is this test needed?
         KConfigGroup cg(config, mGroup);
         if ((mDefault == mReference) && !cg.hasDefault(mKey)) {
-            cg.revertToDefault(mKey);
-        } else if ((mReference >= 0) && (mReference < (int) mChoices.count())) {
-            cg.writeEntry(mKey, mChoices[mReference].name);
+            cg.revertToDefault(mKey, writeFlags());
+        } else if ((mReference >= 0) && (mReference < mChoices.count())) {
+            cg.writeEntry(mKey, mChoices[mReference].name, writeFlags());
         } else {
-            cg.writeEntry(mKey, mReference);
+            cg.writeEntry(mKey, mReference, writeFlags());
         }
         mLoadedValue = mReference;
     }
@@ -879,10 +889,10 @@ void KCoreConfigSkeleton::ItemPathList::writeConfig(KConfig *config)
     if (mReference != mLoadedValue) { // WABA: Is this test needed?
         KConfigGroup cg(config, mGroup);
         if ((mDefault == mReference) && !cg.hasDefault(mKey)) {
-            cg.revertToDefault(mKey);
+            cg.revertToDefault(mKey, writeFlags());
         } else {
             QStringList sl = mReference;
-            cg.writePathEntry(mKey, sl);
+            cg.writePathEntry(mKey, sl, writeFlags());
         }
         mLoadedValue = mReference;
     }
@@ -902,12 +912,12 @@ void KCoreConfigSkeleton::ItemUrlList::readConfig(KConfig *config)
         mReference = mDefault;
     } else {
         QStringList strList;
-        Q_FOREACH (const QUrl &url, mDefault) {
+        for (const QUrl &url : qAsConst(mDefault)) {
             strList.append(url.toString());
         }
         mReference.clear();
         const QStringList readList = cg.readEntry<QStringList>(mKey, strList);
-        Q_FOREACH (const QString &str, readList) {
+        for (const QString &str : readList) {
             mReference.append(QUrl(str));
         }
     }
@@ -921,13 +931,13 @@ void KCoreConfigSkeleton::ItemUrlList::writeConfig(KConfig *config)
     if (mReference != mLoadedValue) { // WABA: Is this test needed?
         KConfigGroup cg(config, mGroup);
         if ((mDefault == mReference) && !cg.hasDefault(mKey)) {
-            cg.revertToDefault(mKey);
+            cg.revertToDefault(mKey, writeFlags());
         } else {
             QStringList strList;
-            Q_FOREACH (const QUrl &url, mReference) {
+            for (const QUrl &url : qAsConst(mReference)) {
                 strList.append(url.toString());
             }
-            cg.writeEntry<QStringList>(mKey, strList);
+            cg.writeEntry<QStringList>(mKey, strList, writeFlags());
         }
         mLoadedValue = mReference;
     }
@@ -945,7 +955,7 @@ bool KCoreConfigSkeleton::ItemUrlList::isEqual(const QVariant &v) const
 
 QVariant KCoreConfigSkeleton::ItemUrlList::property() const
 {
-    return qVariantFromValue<QList<QUrl> >(mReference);
+    return QVariant::fromValue<QList<QUrl> >(mReference);
 }
 
 KCoreConfigSkeleton::ItemIntList::ItemIntList(const QString &_group, const QString &_key,
@@ -980,7 +990,7 @@ bool KCoreConfigSkeleton::ItemIntList::isEqual(const QVariant &v) const
 
 QVariant KCoreConfigSkeleton::ItemIntList::property() const
 {
-    return qVariantFromValue< QList<int> >(mReference);
+    return QVariant::fromValue< QList<int> >(mReference);
 }
 
 //static int kCoreConfigSkeletionDebugArea() { static int s_area = KDebug::registerArea("kdecore (KConfigSkeleton)"); return s_area; }
@@ -999,7 +1009,7 @@ KCoreConfigSkeleton::KCoreConfigSkeleton(KSharedConfig::Ptr pConfig, QObject *pa
       d(new KCoreConfigSkeletonPrivate)
 {
     //qDebug() << "Creating KCoreConfigSkeleton (" << (void *)this << ")";
-    d->mConfig = pConfig;
+    d->mConfig = std::move(pConfig);
 }
 
 KCoreConfigSkeleton::~KCoreConfigSkeleton()
@@ -1034,7 +1044,7 @@ KSharedConfig::Ptr KCoreConfigSkeleton::sharedConfig() const
 
 void KCoreConfigSkeleton::setSharedConfig(KSharedConfig::Ptr pConfig)
 {
-    d->mConfig = pConfig;
+    d->mConfig = std::move(pConfig);
 }
 
 KConfigSkeletonItem::List KCoreConfigSkeleton::items() const
